==> docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0/luna-sdk_alma_rel_v.5.32.0/doc/fsdk/html/search/functions_e.js <==
var searchData=
[
  ['save',['save',['../structfsdk_1_1_i_serializable_object.html#a5171a97d79c639d613ec9d6ee694c8e1',1,'fsdk::ISerializableObject::save()'],['../structfsdk_1_1_i_settings_provider.html#a24c6329c41291b32cdecf5d10cb90a90',1,'fsdk::ISettingsProvider::save()'],['../structfsdk_1_1_image.html#ae3bd0f9b7e1dd8871e7110d566c0eb3b',1,'fsdk::Image::save(const char *path, fsdk::Image::ImageCompression additionalFlag=fsdk::Image::ImageCompression::IC_NO_COMPRESSION) const noexcept'],['../structfsdk_1_1_image.html#a9551bec72e3e4798bce2ddd116b53f6e',1,'fsdk::Image::save(const char *path, const Format format) const noexcept']]],
  ['savetodenseindex',['saveToDenseIndex',['../structfsdk_1_1_i_dynamic_index.html#af7c7947059b6876546e0a712cf32d5bb',1,'fsdk::IDynamicIndex']]],
  ['savetodynamicindex',['saveToDynamicIndex',['../structfsdk_1_1_i_dynamic_index.html#a589098df084d6e99c80574726fc4bca7',1,'fsdk::IDynamicIndex']]],
  ['savetofile',['saveToFile',['../structfsdk_1_1_i_license.html#a0d6ceffe612d0f87dc6ae96bfb4bdb9f',1,'fsdk::ILicense']]],
  ['savetomemory',['saveToMemory',['../structfsdk_1_1_image.html#a394ec678da307c9f6f73b673567bc9ae',1,'fsdk::Image::saveToMemory(Image::Type type, IArchive *archive, fsdk::Image::ImageCompression additionalFlag=fsdk::Image::ImageCompression::IC_NO_COMPRESSION) const noexcept'],['../structfsdk_1_1_image.html#a4031cca84864d83a5361968eaec0809e',1,'fsdk::Image::saveToMemory(Image::Type type, IArchive *archive, const Format format) const noexcept']]],
  ['search',['search',['../structfsdk_1_1_i_index.html#a0f14bf62346477137a85525c03cbf1e5',1,'fsdk::IIndex']]],
  ['searchresult',['SearchResult',['../structfsdk_1_1_search_result.html#a22fc4965d8484ef9ecd8540d2bc86bc8',1,'fsdk::SearchResult::SearchResult() noexcept'],['../structfsdk_1_1_search_result.html#aef457bbb7044f31b2d8d7e788468d2d2',1,'fsdk::SearchResult::SearchResult(float distance, float similarity, DescriptorId index) noexcept']]],
  ['set',['set',['../structfsdk_1_1_image.html#ae43bcd728b9b3389a5d45e20dee1205d',1,'fsdk::Image::set(int width, int height, Format format, const void *data, MemoryResidence residence=MemoryResidence::MemoryCPU, int deviceId=0) noexcept'],['../structfsdk_1_1_image.html#a85ddf384c606013f7c2aa2815eaeccf4',1,'fsdk::Image::set(int width, int height, Format format, void *data, bool copy, MemoryResidence residence=MemoryResidence::MemoryCPU, int deviceId=0) noexcept'],['../structfsdk_1_1_image.html#af449e5eaada6b033205fec916c758aff',1,'fsdk::Image::set(const Image &amp;other) noexcept'],['../structfsdk_1_1_image.html#a62466dd45bd37cdd3c73bdeb7b268b20',1,'fsdk::Image::set(const SubImage &amp;subImage) noexcept'],['../structfsdk_1_1_base_rect.html#a3ce12a4e41011abe8e786c0fbc8ce21d',1,'fsdk::BaseRect::set()'],['../structfsdk_1_1_ref_base.html#a9baae9b19a0723e049bce5d641889662',1,'fsdk::RefBase::set()']]],
  ['setbool',['setBool',['../structfsdk_1_1_i_settings_provider_1_1_value.html#afbdabfa895b18e2ae63429b99accb87b',1,'fsdk::ISettingsProvider::Value']]],
  ['setbottom',['setBottom',['../structfsdk_1_1_base_rect.html#a4b293834cd31533ac8a0a3ddfd1e1329',1,'fsdk::BaseRect']]],
  ['setcustomdetectioncomparer',['setCustomDetectionComparer',['../structfsdk_1_1_i_detector.html#aaf4ac12ce269c0cc293f9348f9ef1c3d',1,'fsdk::IDetector']]],
  ['setdatadirectory',['setDataDirectory',['../structfsdk_1_1_i_face_engine.html#a58eb8660079affaa0d3e9b684e751479',1,'fsdk::IFaceEngine::setDataDirectory()'],['../group___core_group.html#ga3384924bf4b9d7287e7017b82d24af6e',1,'fsdk::IFaceEnginePos::setDataDirectory()']]],
  ['setdefaultpath',['setDefaultPath',['../structfsdk_1_1_i_settings_provider.html#a0e2b7cad3c544381a4e5a9130b96753e',1,'fsdk::ISettingsProvider']]],
  ['setdesc',['setDesc',['../structfsdk_1_1_i_settings_provider_1_1_desc.html#af5c231731f8657154468cfc4ba7e3096',1,'fsdk::ISettingsProvider::Desc::setDesc()'],['../structfsdk_1_1_i_settings_provider_1_1_entry.html#a462b8686b4b770c5204a4a5031514fb9',1,'fsdk::ISettingsProvider::Entry::setDesc()'],['../structfsdk_1_1_i_settings_provider.html#ac9dd8729888381082f1fd9ec46734db2',1,'fsdk::ISettingsProvider::setDesc(const Key &amp;key, const Desc &amp;desc) noexcept=0'],['../structfsdk_1_1_i_settings_provider.html#aabb9a7e6bd022bc5fd89d019a74628d0',1,'fsdk::ISettingsProvider::setDesc(const char *section, const char *parameter, const Desc &amp;desc) noexcept']]],
  ['setdescriptor',['setDescriptor',['../structfsdk_1_1_i_descriptor.html#a430f0098d482b8f235f0b0282184c864',1,'fsdk::IDescriptor']]],
  ['setdetectioncomparer',['setDetectionComparer',['../structfsdk_1_1_i_detector.html#a19a8d0891929e7e922a2f1282076d8a9',1,'fsdk::IDetector']]],
  ['setentry',['setEntry',['../structfsdk_1_1_i_settings_provider.html#a24483db5f2e2b8434cb226d23e8f767d',1,'fsdk::ISettingsProvider::setEntry(const Key &amp;key, Entry &amp;&amp;entry) noexcept=0'],['../structfsdk_1_1_i_settings_provider.html#abedbf12597aee1d33e7f42c47fa9b18a',1,'fsdk::ISettingsProvider::setEntry(const Key &amp;key, const Desc &amp;desc, Value &amp;&amp;value) noexcept'],['../structfsdk_1_1_i_settings_provider.html#a44255bcd4c2f6697782082033f1c062e',1,'fsdk::ISettingsProvider::setEntry(const char *section, const char *parameter, const Desc &amp;desc, Value &amp;&amp;value) noexcept']]],
  ['setfloat',['setFloat',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a4e86e07ec3d3dd9fa6df83af423b147e',1,'fsdk::ISettingsProvider::Value::setFloat(float x) noexcept'],['../structfsdk_1_1_i_settings_provider_1_1_value.html#a5720f7b47ca5264c9da56cb8659fff40',1,'fsdk::ISettingsProvider::Value::setFloat(float x, float y) noexcept'],['../structfsdk_1_1_i_settings_provider_1_1_value.html#af6de22e8a4956661ef47b65adbc7684f',1,'fsdk::ISettingsProvider::Value::setFloat(float x, float y, float z) noexcept'],['../structfsdk_1_1_i_settings_provider_1_1_value.html#aefc7af5a886571f1e510c1eb51558c06',1,'fsdk::ISettingsProvider::Value::setFloat(float x, float y, float z, float w) noexcept']]],
  ['setint',['setInt',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a8ffc8d4baa19ff98c25b3ca1cdec419d',1,'fsdk::ISettingsProvider::Value::setInt(int x) noexcept'],['../structfsdk_1_1_i_settings_provider_1_1_value.html#a4b8b66e59cbdc206fc389f486ac9da69',1,'fsdk::ISettingsProvider::Value::setInt(int x, int y) noexcept'],['../structfsdk_1_1_i_settings_provider_1_1_value.html#abf9c6a2457cf1f7cc856533aefd85d9d',1,'fsdk::ISettingsProvider::Value::setInt(int x, int y, int z) noexcept'],['../structfsdk_1_1_i_settings_provider_1_1_value.html#a999198508b6f0f7ec19daff50424343b',1,'fsdk::ISettingsProvider::Value::setInt(int x, int y, int z, int w) noexcept']]],
  ['setleft',['setLeft',['../structfsdk_1_1_base_rect.html#ab4466df98371077db3f9184894d7af32',1,'fsdk::BaseRect']]],
  ['setparameter',['setParameter',['../structfsdk_1_1_i_settings_provider_1_1_key.html#a4806cf422efe957999b8b1578f716d4b',1,'fsdk::ISettingsProvider::Key']]],
  ['setpoint2f',['setPoint2f',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a97c411b847afda41ec7b64a0e646e6e6',1,'fsdk::ISettingsProvider::Value']]],
  ['setpoint2i',['setPoint2i',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a2a6a2b04795f4be07002b554877951b0',1,'fsdk::ISettingsProvider::Value']]],
  ['setprintfunction',['setPrintFunction',['../_log_8h.html#a2513f0c4589afb6021a0a93f03023202',1,'fsdk::log']]],
  ['setrawrect',['setRawRect',['../structfsdk_1_1_detection.html#a6425f5f8ddc50c94df035378bb3d5aee',1,'fsdk::Detection']]],
  ['setrect',['setRect',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a33745b6b63863e2153867c888257a373',1,'fsdk::ISettingsProvider::Value']]],
  ['setright',['setRight',['../structfsdk_1_1_base_rect.html#a137f59a19b449cee39e36e9b68bca4e2',1,'fsdk::BaseRect']]],
  ['setruntimesettingsprovider',['setRuntimeSettingsProvider',['../structfsdk_1_1_i_face_engine.html#ae7e6ca6f139b0bd46581cf98c265ea5e',1,'fsdk::IFaceEngine::setRuntimeSettingsProvider()'],['../group___core_group.html#gab94cfa9a393ce00910e0619cceb560a9',1,'fsdk::IFaceEnginePos::setRuntimeSettingsProvider()']]],
  ['setscore',['setScore',['../structfsdk_1_1_detection.html#a63d72cc33b96c33a078961b5f0b23ac5',1,'fsdk::Detection']]],
  ['setsection',['setSection',['../structfsdk_1_1_i_settings_provider_1_1_key.html#acb298366c5ad703f47add965f31420ed',1,'fsdk::ISettingsProvider::Key']]],
  ['setsettingsprovider',['setSettingsProvider',['../structfsdk_1_1_i_face_engine.html#af379531b6060c674591c722b3b71a6c2',1,'fsdk::IFaceEngine::setSettingsProvider()'],['../group___core_group.html#ga46bd93c74b94d27d48a3d06849d4095c',1,'fsdk::IFaceEnginePos::setSettingsProvider()']]],
  ['setseverityfilter',['setSeverityFilter',['../_log_8h.html#a4feee1207af3723856efe93af4149a05',1,'fsdk::log']]],
  ['setsize',['setSize',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a98e8b1488035f0329ffc81180143398e',1,'fsdk::ISettingsProvider::Value::setSize()'],['../classfsdk_1_1_span.html#ac6eff7f7e3d1fedb1673b4411d9a3de9',1,'fsdk::Span::setSize()']]],
  ['setsizehint',['setSizeHint',['../structfsdk_1_1_i_archive.html#a7f1fe72083db24c7b6620d4a9a657612',1,'fsdk::IArchive']]],
  ['setstring',['setString',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a730243dec9aa8addb47d58b11806dafa',1,'fsdk::ISettingsProvider::Value']]],
  ['settop',['setTop',['../structfsdk_1_1_base_rect.html#a1f55e47d552e914b58061632cb35e20f',1,'fsdk::BaseRect']]],
  ['setvalue',['setValue',['../structfsdk_1_1_i_settings_provider_1_1_entry.html#a0f18fe3e34e0546f8bb7e8ec89ac2b7f',1,'fsdk::ISettingsProvider::Entry::setValue()'],['../structfsdk_1_1_i_settings_provider.html#a98efbcbf26e39e5cf70b3215514d5975',1,'fsdk::ISettingsProvider::setValue(const Key &amp;key, Value &amp;&amp;value) noexcept=0'],['../structfsdk_1_1_i_settings_provider.html#a6472ad96f6b21bbf36fbbd4e4473bb50',1,'fsdk::ISettingsProvider::setValue(const char *section, const char *parameter, Value &amp;&amp;value) noexcept']]],
  ['size',['size',['../structfsdk_1_1_i_static_descriptor_storage.html#aee1e7ce2800e384e546d7d99de7ca586',1,'fsdk::IStaticDescriptorStorage::size()'],['../structfsdk_1_1_base_rect.html#a270bd8113a22c7f5cc553a1baa362ba3',1,'fsdk::BaseRect::size()'],['../classfsdk_1_1_span.html#a58c4fe6ff3f3a439ef6a3af5ec2fd021',1,'fsdk::Span::size()']]],
  ['sizer',['Sizer',['../structfsdk_1_1_sizer.html#a9cd97626466e7e07a63fe9ff896352dc',1,'fsdk::Sizer::Sizer() noexcept'],['../structfsdk_1_1_sizer.html#a491defed47cfaeaf38dd29074c8b7d89',1,'fsdk::Sizer::Sizer(const Sizer &amp;other) noexcept']]],
  ['span',['Span',['../classfsdk_1_1_span.html#ae984b657d4947a6adb3e1d0b4ddce297',1,'fsdk::Span::Span(T *data, std::size_t size)'],['../classfsdk_1_1_span.html#ad269a8eb69d0d90e34d8eab02d575cc6',1,'fsdk::Span::Span(ContiguousContainer &amp;&amp;container)']]],
  ['state',['state',['../classfsdk_1_1_future.html#a2b52e6264dc9fb54d143712efdb783b8',1,'fsdk::Future::state()'],['../classfsdk_1_1_promise.html#acb099562ad549c712fcdca295b379f5d',1,'fsdk::Promise::state()']]],
  ['stop',['stop',['../structfsdk_1_1_i_async_context.html#af9133106ddd66cfc4bbb48d390e48f2c',1,'fsdk::IAsyncContext']]],
  ['subimage',['SubImage',['../structfsdk_1_1_sub_image.html#a1ccb24d83a92805fad4aa5c18f43b114',1,'fsdk::SubImage']]],
  ['swap',['swap',['../classfsdk_1_1_future.html#a7f7977f3ac4805fda79869a23f9f8686',1,'fsdk::Future::swap()'],['../classfsdk_1_1_promise.html#a9b3e58dc95742108177ca25db4a933eb',1,'fsdk::Promise::swap()'],['../structfsdk_1_1_image.html#a6cc848e22d99f4d2d8b34d240c0bba47',1,'fsdk::Image::swap()'],['../structfsdk_1_1_sizer.html#af49cc6ba59d47f9fd71a461260231a4e',1,'fsdk::Sizer::swap()']]]
];

==> docs_sdk_archive_luna-sdk_alma_rel_v.5.34.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.34.0/luna-sdk_alma_rel_v.5.34.0/doc/fsdk/html/search/functions_e.js <==
var searchData=
[
  ['save',['save',['../structfsdk_1_1_i_serializable_object.html#a5171a97d79c639d613ec9d6ee694c8e1',1,'fsdk::ISerializableObject::save()'],['../structfsdk_1_1_i_settings_provider.html#a24c6329c41291b32cdecf5d10cb90a90',1,'fsdk::ISettingsProvider::save()'],['../structfsdk_1_1_image.html#ae3bd0f9b7e1dd8871e7110d566c0eb3b',1,'fsdk::Image::save(const char *path, fsdk::Image::ImageCompression additionalFlag=fsdk::Image::ImageCompression::IC_NO_COMPRESSION) const noexcept'],['../structfsdk_1_1_image.html#a9551bec72e3e4798bce2ddd116b53f6e',1,'fsdk::Image::save(const char *path, const Format format) const noexcept']]],
  ['savetodenseindex',['saveToDenseIndex',['../structfsdk_1_1_i_dynamic_index.html#af7c7947059b6876546e0a712cf32d5bb',1,'fsdk::IDynamicIndex']]],
  ['savetodynamicindex',['saveToDynamicIndex',['../structfsdk_1_1_i_dynamic_index.html#a589098df084d6e99c80574726fc4bca7',1,'fsdk::IDynamicIndex']]],
  ['savetofile',['saveToFile',['../structfsdk_1_1_i_license.html#a0d6ceffe612d0f87dc6ae96bfb4bdb9f',1,'fsdk::ILicense']]],
  ['savetomemory',['saveToMemory',['../structfsdk_1_1_image.html#a394ec678da307c9f6f73b673567bc9ae',1,'fsdk::Image::saveToMemory(Image::Type type, IArchive *archive, fsdk::Image::ImageCompression additionalFlag=fsdk::Image::ImageCompression::IC_NO_COMPRESSION) const noexcept'],['../structfsdk_1_1_image.html#a4031cca84864d83a5361968eaec0809e',1,'fsdk::Image::saveToMemory(Image::Type type, IArchive *archive, const Format format) const noexcept']]],
  ['search',['search',['../structfsdk_1_1_i_index.html#a0f14bf62346477137a85525c03cbf1e5',1,'fsdk::IIndex']]],
  ['searchresult',['SearchResult',['../structfsdk_1_1_search_result.html#a22fc4965d8484ef9ecd8540d2bc86bc8',1,'fsdk::SearchResult::SearchResult() noexcept'],['../structfsdk_1_1_search_result.html#aef457bbb7044f31b2d8d7e788468d2d2',1,'fsdk::SearchResult::SearchResult(float distance, float similarity, DescriptorId index) noexcept']]],
  ['set',['set',['../structfsdk_1_1_image.html#ae43bcd728b9b3389a5d45e20dee1205d',1,'fsdk::Image::set(int width, int height, Format format, const void *data, MemoryResidence residence=MemoryResidence::MemoryCPU, int deviceId=0) noexcept'],['../structfsdk_1_1_image.html#a85ddf384c606013f7c2aa2815eaeccf4',1,'fsdk::Image::set(int width, int height, Format format, void *data, bool copy, MemoryResidence residence=MemoryResidence::MemoryCPU, int deviceId=0) noexcept'],['../structfsdk_1_1_image.html#af449e5eaada6b033205fec916c758aff',1,'fsdk::Image::set(const Image &amp;other) noexcept'],['../structfsdk_1_1_image.html#a62466dd45bd37cdd3c73bdeb7b268b20',1,'fsdk::Image::set(const SubImage &amp;subImage) noexcept'],['../structfsdk_1_1_base_rect.html#a3ce12a4e41011abe8e786c0fbc8ce21d',1,'fsdk::BaseRect::set()'],['../structfsdk_1_1_ref_base.html#a9baae9b19a0723e049bce5d641889662',1,'fsdk::RefBase::set()']]],
  ['setbool',['setBool',['../structfsdk_1_1_i_settings_provider_1_1_value.html#afbdabfa895b18e2ae63429b99accb87b',1,'fsdk::ISettingsProvider::Value']]],
  ['setbottom',['setBottom',['../structfsdk_1_1_base_rect.html#a4b293834cd31533ac8a0a3ddfd1e1329',1,'fsdk::BaseRect']]],
  ['setcustomdetectioncomparer',['setCustomDetectionComparer',['../structfsdk_1_1_i_detector.html#aaf4ac12ce269c0cc293f9348f9ef1c3d',1,'fsdk::IDetector']]],
  ['setdatadirectory',['setDataDirectory',['../structfsdk_1_1_i_face_engine.html#a58eb8660079affaa0d3e9b684e751479',1,'fsdk::IFaceEngine::setDataDirectory()'],['../group___core_group.html#ga3384924bf4b9d7287e7017b82d24af6e',1,'fsdk::IFaceEnginePos::setDataDirectory()']]],
  ['setdefaultpath',['setDefaultPath',['../structfsdk_1_1_i_settings_provider.html#a0e2b7cad3c544381a4e5a9130b96753e',1,'fsdk::ISettingsProvider']]],
  ['setdesc',['setDesc',['../structfsdk_1_1_i_settings_provider_1_1_desc.html#af5c231731f8657154468cfc4ba7e3096',1,'fsdk::ISettingsProvider::Desc::setDesc()'],['../structfsdk_1_1_i_settings_provider_1_1_entry.html#a462b8686b4b770c5204a4a5031514fb9',1,'fsdk::ISettingsProvider::Entry::setDesc()'],['../structfsdk_1_1_i_settings_provider.html#ac9dd8729888381082f1fd9ec46734db2',1,'fsdk::ISettingsProvider::setDesc(const Key &amp;key, const Desc &amp;desc) noexcept=0'],['../structfsdk_1_1_i_settings_provider.html#aabb9a7e6bd022bc5fd89d019a74628d0',1,'fsdk::ISettingsProvider::setDesc(const char *section, const char *parameter, const Desc &amp;desc) noexcept']]],
  ['setdescriptor',['setDescriptor',['../structfsdk_1_1_i_descriptor.html#a430f0098d482b8f235f0b0282184c864',1,'fsdk::IDescriptor']]],
  ['setdetectioncomparer',['setDetectionComparer',['../structfsdk_1_1_i_detector.html#a19a8d0891929e7e922a2f1282076d8a9',1,'fsdk::IDetector']]],
  ['setentry',['setEntry',['../structfsdk_1_1_i_settings_provider.html#a24483db5f2e2b8434cb226d23e8f767d',1,'fsdk::ISettingsProvider::setEntry(const Key &amp;key, Entry &amp;&amp;entry) noexcept=0'],['../structfsdk_1_1_i_settings_provider.html#abedbf12597aee1d33e7f42c47fa9b18a',1,'fsdk::ISettingsProvider::setEntry(const Key &amp;key, const Desc &amp;desc, Value &amp;&amp;value) noexcept'],['../structfsdk_1_1_i_settings_provider.html#a44255bcd4c2f6697782082033f1c062e',1,'fsdk::ISettingsProvider::setEntry(const char *section, const char *parameter, const Desc &amp;desc, Value &amp;&amp;value) noexcept']]],
  ['setfloat',['setFloat',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a4e86e07ec3d3dd9fa6df83af423b147e',1,'fsdk::ISettingsProvider::Value::setFloat(float x) noexcept'],['../structfsdk_1_1_i_settings_provider_1_1_value.html#a5720f7b47ca5264c9da56cb8659fff40',1,'fsdk::ISettingsProvider::Value::setFloat(float x, float y) noexcept'],['../structfsdk_1_1_i_settings_provider_1_1_value.html#af6de22e8a4956661ef47b65adbc7684f',1,'fsdk::ISettingsProvider::Value::setFloat(float x, float y, float z) noexcept'],['../structfsdk_1_1_i_settings_provider_1_1_value.html#aefc7af5a886571f1e510c1eb51558c06',1,'fsdk::ISettingsProvider::Value::setFloat(float x, float y, float z, float w) noexcept']]],
  ['setint',['setInt',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a8ffc8d4baa19ff98c25b3ca1cdec419d',1,'fsdk::ISettingsProvider::Value::setInt(int x) noexcept'],['../structfsdk_1_1_i_settings_provider_1_1_value.html#a4b8b66e59cbdc206fc389f486ac9da69',1,'fsdk::ISettingsProvider::Value::setInt(int x, int y) noexcept'],['../structfsdk_1_1_i_settings_provider_1_1_value.html#abf9c6a2457cf1f7cc856533aefd85d9d',1,'fsdk::ISettingsProvider::Value::setInt(int x, int y, int z) noexcept'],['../structfsdk_1_1_i_settings_provider_1_1_value.html#a999198508b6f0f7ec19daff50424343b',1,'fsdk::ISettingsProvider::Value::setInt(int x, int y, int z, int w) noexcept']]],
  ['setleft',['setLeft',['../structfsdk_1_1_base_rect.html#ab4466df98371077db3f9184894d7af32',1,'fsdk::BaseRect']]],
  ['setparameter',['setParameter',['../structfsdk_1_1_i_settings_provider_1_1_key.html#a4806cf422efe957999b8b1578f716d4b',1,'fsdk::ISettingsProvider::Key']]],
  ['setpoint2f',['setPoint2f',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a97c411b847afda41ec7b64a0e646e6e6',1,'fsdk::ISettingsProvider::Value']]],
  ['setpoint2i',['setPoint2i',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a2a6a2b04795f4be07002b554877951b0',1,'fsdk::ISettingsProvider::Value']]],
  ['setprintfunction',['setPrintFunction',['../_log_8h.html#a2513f0c4589afb6021a0a93f03023202',1,'fsdk::log']]],
  ['setrawrect',['setRawRect',['../structfsdk_1_1_detection.html#a6425f5f8ddc50c94df035378bb3d5aee',1,'fsdk::Detection']]],
  ['setrect',['setRect',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a33745b6b63863e2153867c888257a373',1,'fsdk::ISettingsProvider::Value']]],
  ['setright',['setRight',['../structfsdk_1_1_base_rect.html#a137f59a19b449cee39e36e9b68bca4e2',1,'fsdk::BaseRect']]],
  ['setruntimesettingsprovider',['setRuntimeSettingsProvider',['../structfsdk_1_1_i_face_engine.html#ae7e6ca6f139b0bd46581cf98c265ea5e',1,'fsdk::IFaceEngine::setRuntimeSettingsProvider()'],['../group___core_group.html#gab94cfa9a393ce00910e0619cceb560a9',1,'fsdk::IFaceEnginePos::setRuntimeSettingsProvider()']]],
  ['setscore',['setScore',['../structfsdk_1_1_detection.html#a63d72cc33b96c33a078961b5f0b23ac5',1,'fsdk::Detection']]],
  ['setsection',['setSection',['../structfsdk_1_1_i_settings_provider_1_1_key.html#acb298366c5ad703f47add965f31420ed',1,'fsdk::ISettingsProvider::Key']]],
  ['setsettingsprovider',['setSettingsProvider',['../structfsdk_1_1_i_face_engine.html#af379531b6060c674591c722b3b71a6c2',1,'fsdk::IFaceEngine::setSettingsProvider()'],['../group___core_group.html#ga46bd93c74b94d27d48a3d06849d4095c',1,'fsdk::IFaceEnginePos::setSettingsProvider()']]],
  ['setseverityfilter',['setSeverityFilter',['../_log_8h.html#a4feee1207af3723856efe93af4149a05',1,'fsdk::log']]],
  ['setsize',['setSize',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a98e8b1488035f0329ffc81180143398e',1,'fsdk::ISettingsProvider::Value::setSize()'],['../classfsdk_1_1_span.html#ac6eff7f7e3d1fedb1673b4411d9a3de9',1,'fsdk::Span::setSize()']]],
  ['setsizehint',['setSizeHint',['../structfsdk_1_1_i_archive.html#a7f1fe72083db24c7b6620d4a9a657612',1,'fsdk::IArchive']]],
  ['setstring',['setString',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a730243dec9aa8addb47d58b11806dafa',1,'fsdk::ISettingsProvider::Value']]],
  ['settop',['setTop',['../structfsdk_1_1_base_rect.html#a1f55e47d552e914b58061632cb35e20f',1,'fsdk::BaseRect']]],
  ['setulong',['setULong',['../structfsdk_1_1_i_settings_provider_1_1_value.html#ac6848b8df1635e6d75ac5b7782737040',1,'fsdk::ISettingsProvider::Value']]],
  ['setvalue',['setValue',['../structfsdk_1_1_i_settings_provider_1_1_entry.html#a0f18fe3e34e0546f8bb7e8ec89ac2b7f',1,'fsdk::ISettingsProvider::Entry::setValue()'],['../structfsdk_1_1_i_settings_provider.html#a98efbcbf26e39e5cf70b3215514d5975',1,'fsdk::ISettingsProvider::setValue(const Key &amp;key, Value &amp;&amp;value) noexcept=0'],['../structfsdk_1_1_i_settings_provider.html#a6472ad96f6b21bbf36fbbd4e4473bb50',1,'fsdk::ISettingsProvider::setValue(const char *section, const char *parameter, Value &amp;&amp;value) noexcept']]],
  ['size',['size',['../structfsdk_1_1_i_static_descriptor_storage.html#aee1e7ce2800e384e546d7d99de7ca586',1,'fsdk::IStaticDescriptorStorage::size()'],['../structfsdk_1_1_base_rect.html#a270bd8113a22c7f5cc553a1baa362ba3',1,'fsdk::BaseRect::size()'],['../classfsdk_1_1_span.html#a58c4fe6ff3f3a439ef6a3af5ec2fd021',1,'fsdk::Span::size()']]],
  ['sizer',['Sizer',['../structfsdk_1_1_sizer.html#a9cd97626466e7e07a63fe9ff896352dc',1,'fsdk::Sizer::Sizer() noexcept'],['../structfsdk_1_1_sizer.html#a491defed47cfaeaf38dd29074c8b7d89',1,'fsdk::Sizer::Sizer(const Sizer &amp;other) noexcept']]],
  ['span',['Span',['../classfsdk_1_1_span.html#ae984b657d4947a6adb3e1d0b4ddce297',1,'fsdk::Span::Span(T *data, std::size_t size)'],['../classfsdk_1_1_span.html#ad269a8eb69d0d90e34d8eab02d575cc6',1,'fsdk::Span::Span(ContiguousContainer &amp;&amp;container)']]],
  ['state',['state',['../classfsdk_1_1_future.html#a2b52e6264dc9fb54d143712efdb783b8',1,'fsdk::Future::state()'],['../classfsdk_1_1_promise.html#acb099562ad549c712fcdca295b379f5d',1,'fsdk::Promise::state()']]],
  ['stop',['stop',['../structfsdk_1_1_i_async_context.html#af9133106ddd66cfc4bbb48d390e48f2c',1,'fsdk::IAsyncContext']]],
  ['subimage',['SubImage',['../structfsdk_1_1_sub_image.html#a1ccb24d83a92805fad4aa5c18f43b114',1,'fsdk::SubImage']]],
  ['swap',['swap',['../classfsdk_1_1_future.html#a7f7977f3ac4805fda79869a23f9f8686',1,'fsdk::Future::swap()'],['../classfsdk_1_1_promise.html#a9b3e58dc95742108177ca25db4a933eb',1,'fsdk::Promise::swap()'],['../structfsdk_1_1_image.html#a6cc848e22d99f4d2d8b34d240c0bba47',1,'fsdk::Image::swap()'],['../structfsdk_1_1_sizer.html#af49cc6ba59d47f9fd71a461260231a4e',1,'fsdk::Sizer::swap()']]]
];
